"""
Views for managing pages.

:copyright: Copyright 2013-2016, Dorian Pula <dorian.pula@amber-penguin-software.ca>
:license: AGPL v3+
"""

import logging

import flask

from rookeries.database import db
from rookeries.main import rookeries_app
from rookeries.pages import models
from rookeries.vendors import flask_jwt

logger = logging.getLogger(__name__)


@rookeries_app.route('/api/pages', methods=['GET'])
def serve_landing_page():
    """
    Serving up a landing page with Markdown content.

    :request page: The name of the page to display.
    """
    # TODO: Remove hardcoding of landing url
    return serve_page('about')


@rookeries_app.route('/api/pages/<slug>', methods=['GET'])
def serve_page(slug):
    """
    Serving up a page with Markdown content.

    :request page: The name of the page to display.
    """
    logger.info('Retrieving page "%s"', slug)
    page = models.Page.query.filter_by(slug=slug).first_or_404()
    return flask.jsonify(page.to_json())


@rookeries_app.route('/api/pages/<slug>', methods=['POST', 'PUT'])
@flask_jwt.jwt_required()
def save_page(slug):
    updated_page = flask.request.json
    page = models.Page.query.filter_by(slug=slug).first()
    if not page:
        page = models.Page(
            slug=slug,
            title=updated_page['title'],
            content=updated_page['content'])
        db.session.add(page)

    else:
        page.slug = slug
        page.title = updated_page['title']
        page.content = updated_page['content']

    db.session.commit()
    return flask.jsonify(page.to_json())
