"""
Models for sites.

:copyright: Copyright 2013-2016, Dorian Pula <dorian.pula@amber-penguin-software.ca>
:license: AGPL v3+
"""

import uuid

from sqlalchemy_utils.types import url as sql_url, uuid as sql_uuid

from rookeries.database import db


class Site(db.Model):
    __tablename__ = 'site'

    id = db.Column(db.Integer, primary_key=True)
    api_key = db.Column(sql_uuid.UUIDType, unique=True, nullable=False)
    name = db.Column(db.String(64))
    url = db.Column(sql_url.URLType)

    # TODO: Add in tag line, copyright notice, favicon and logo image, other attributes in here.
    config = db.Column(db.JSON)
    menu = db.relationship('SiteMenu', order_by='SiteMenu.orderinal', back_populates='site')

    def __init__(self, name, url, config=None, api_key=None):
        self.name = name
        self.url = url
        self.config = config or {}
        self.api_key = api_key or uuid.uuid4()

    def __repr__(self) -> str:
        return f'<Site {self.name} - {self.url}>'

    def to_json(self) -> dict:
        return {
            'api_key': self.api_key,
            'name': self.name,
            'url': self.url,
            'config': self.config,
        }


class SiteMenu(db.Model):
    __tablename__ = 'site_menu'

    id = db.Column(db.Integer, primary_key=True)
    orderinal = db.Column(db.Integer)
    title = db.Column(db.String)

    site_id = db.Column(db.Integer, db.ForeignKey('site.id'))
    site = db.relationship('Site', back_populates='menu')

    page_id = db.Column(db.Integer, db.ForeignKey('page.id'))
    page = db.relationship('Page')

    def __init__(self, title, site, page, orderinal=0):
        self.title = title
        self.site = site
        self.page = page
        self.orderinal = orderinal

    def __repr__(self) -> str:
        return f'<SiteMenu {self.orderinal} - {self.title}>'

    def to_json(self) -> dict:
        return {
            'title': self.title,
            'orderinal': self.orderinal,
            'page': self.page.slug,
            # TODO: Improve this into something more regular.
            'url': '/' + self.page.slug,
        }
