"""
Core web application views.

:copyright: Copyright 2013-2016, Dorian Pula <dorian.pula@amber-penguin-software.ca>
:license: AGPL v3+
"""

import io
import logging
import os

import flask

import rookeries
from rookeries.main import rookeries_app

logger = logging.getLogger(__name__)

GIT_REVISION_INFO_FILE = './git-info'


def get_git_revision():
    if not os.path.exists(GIT_REVISION_INFO_FILE):
        return 'UNKNOWN'

    with io.open(GIT_REVISION_INFO_FILE) as git_info:
        revision_info = git_info.readlines()[0].strip()
    return revision_info or 'UNKNOWN'


@rookeries_app.route('/status')
def app_status():
    """Simple view that returns the status of the application.  Useful as a part of a heartbeat mechanism."""
    app_status_info = {
        'app': 'rookeries',
        'version': rookeries.__version__,
        'gitRevision': get_git_revision(),
    }

    return flask.jsonify(app_status_info)
