"""
Unit tests for testing serving of page content.

:copyright: Copyright 2013-2016, Dorian Pula <dorian.pula@amber-penguin-software.ca>
:license: AGPL v3+
"""

import http

import pytest
import requests
import sqlalchemy

from rookeries.pages import models

TEST_PAGE_TITLE = 'Testing Page'
TEST_PAGE_SLUG = 'test'
TEST_PAGE_CONTENT = '''
# Hello World
I'm a test page.
'''


# TODO: Change these tests to be bdd style functional tests.

@pytest.fixture(scope='module')
def test_page(db_engine):
    session = sqlalchemy.orm.sessionmaker(bind=db_engine, autocommit=True)()
    session.begin()
    test_page = session.query(models.Page).filter_by(slug=TEST_PAGE_SLUG).first()
    if not test_page:
        test_page = models.Page(slug=TEST_PAGE_SLUG, title=TEST_PAGE_TITLE, content=TEST_PAGE_CONTENT)
        session.add(test_page)
    test_page = session.query(models.Page).filter_by(slug=TEST_PAGE_SLUG).first()
    test_page_json = test_page.to_json()
    session.commit()
    session.close()
    return test_page_json


def test_serve_page_returns_journal_entry_as_json(api_base_uri, test_page):
    expected_info = {
        'slug': TEST_PAGE_SLUG,
        'title': TEST_PAGE_TITLE,
        'content': TEST_PAGE_CONTENT,
    }

    actual = requests.get(f'{api_base_uri}/api/pages/{TEST_PAGE_SLUG}')

    assert actual.status_code == http.HTTPStatus.OK
    assert actual.json() == expected_info


@pytest.mark.skip('Expected behaviour for a landing page is not properly defined.')
def test_serve_landing_page_view_returns_about_page(api_base_uri, test_page):
    expected_info = {
        'slug': 'about',
        'title': 'About Rookeries',
        'content': '# About Rookeries',
    }

    actual = requests.get(f'{api_base_uri}/api/pages')

    assert actual.status_code == http.HTTPStatus.OK
    assert actual.json() == expected_info


def test_serve_page_view_returns_404_when_no_content_found(api_base_uri, test_page):
    expected_json = {
        'error': {
            'status_code': 404,
            'message': 'Resource not found.',
            'resource': f'{api_base_uri}/api/pages/missing',
        }
    }

    actual = requests.get(f'{api_base_uri}/api/pages/missing')

    assert actual.status_code == http.HTTPStatus.NOT_FOUND
    assert actual.json() == expected_json
