Feature: User Management
  The user endpoints allows an app admin user to create, modify and delete users.  User can modify their profiles.

## User Creation

Scenario: Admin user can create a new admin user
  Given I am an admin user
  And I try to create an admin user
  Then I get a new admin user

Scenario: Admin user can create a new editor user
  Given I am an admin user
  And I try to create an editor user
  Then I get a new editor user

Scenario: Admin user can create a new subscriber user
  Given I am an admin user
  And I try to create a subscriber user
  Then I get a new subscriber user

Scenario: User cannot create a user using a non-json response
  Given I am an admin user
  And I try to create an admin user with non-json request
  Then I get a bad request response

Scenario: User cannot create a user using a non-json response
  Given I am an admin user
  And I try to create an admin user with an empty-json request
  Then I get a bad request response

Scenario: Editor user can not create a new admin user
  Given I am an editor user
  And I try to create an admin user
  Then I get an unauthorized response

Scenario: Editor user can not create a new subscriber user
  Given I am an editor user
  And I try to create a subscriber user
  Then I get an unauthorized response

Scenario: Editor user can not create a new editor user
  Given I am an editor user
  And I try to create an editor user
  Then I get an unauthorized response

Scenario: Subscriber user can not create a new admin user
  Given I am an subscriber user
  And I try to create an admin user
  Then I get an unauthorized response

Scenario: Subscriber user can not create a new subscriber user
  Given I am an subscriber user
  And I try to create a subscriber user
  Then I get an unauthorized response

Scenario: Subscriber user can not create a new editor user
  Given I am an subscriber user
  And I try to create an editor user
  Then I get an unauthorized response

## User Access

Scenario: Admin user can get an existing admin user
  Given I am an admin user
  And I try to get an admin user
  Then I get an admin user

Scenario: Admin user can get an existing editor user
  Given I am an admin user
  And I try to get an editor user
  Then I get an editor user

Scenario: Admin user can get own profile
  Given I am an admin user
  And I try to get my admin user
  Then I get my admin user

Scenario: Admin user can not get an non-existent user
  Given I am an admin user
  And I try to get an non-existent user
  Then I get a user can not be found message

Scenario: Editor user can not get an existing admin user
  Given I am an editor user
  And I try to get an admin user
  Then I get an unauthorized response

Scenario: Editor user can not get an existing editor user that is not me
  Given I am an editor user
  And I try to get an editor user
  Then I get an unauthorized response

Scenario: Editor user can get own profile
  Given I am an editor user
  And I try to get my editor user
  Then I get my editor user

Scenario: Subscriber user can not get an existing admin user
  Given I am a subscriber user
  And I try to get an admin user
  Then I get an unauthorized response

Scenario: Subscriber user can not get an existing editor user
  Given I am a subscriber user
  And I try to get an editor user
  Then I get an unauthorized response

Scenario: Subscriber user can not get an subscriber user that is not me
  Given I am a subscriber user
  And I try to get an subscriber user
  Then I get an unauthorized response

Scenario: Subscriber user can get own profile
  Given I am a subscriber user
  And I try to get my subscriber user
  Then I get my subscriber user

# User Modification

Scenario: User cannot modify a user using a non-json response
  Given I am an admin user
  And I try to modify an admin user with non-json request
  Then I get a bad request response

Scenario: User cannot modify a user using a non-json response
  Given I am an admin user
  And I try to modify an admin user with an empty-json request
  Then I get a bad request response

Scenario: Admin user can modify an admin user
  Given I am an admin user
  And I try to modify an admin user
  Then updates to the admin user are preserved

Scenario: Admin user can modify an editor user
  Given I am an admin user
  And I try to modify an editor user
  Then updates to the editor user are preserved

Scenario: Admin user can modify an subscriber user
  Given I am an admin user
  And I try to modify a subscriber user
  Then updates to the subscriber user are preserved

Scenario: Editor user can not modify an admin user
  Given I am an editor user
  And I try to modify an admin user
  Then I get an unauthorized response

Scenario: Editor user can not modify an editor user that is not self
  Given I am an editor user
  And I try to modify an editor user
  Then I get an unauthorized response

Scenario: Editor user can modify their own user
  Given I am an editor user
  And I try to modify my editor user
  Then updates to my editor user are preserved

Scenario: Editor user can not modify a subscriber user
  Given I am an editor user
  And I try to modify a subscriber user
  Then I get an unauthorized response

Scenario: Subscriber user can not modify an admin user
  Given I am an subscriber user
  And I try to modify an admin user
  Then I get an unauthorized response

Scenario: Subscriber user can not modify an editor user
  Given I am an subscriber user
  And I try to modify an editor user
  Then I get an unauthorized response

Scenario: Subscriber user can modify their own user
  Given I am an subscriber user
  And I try to modify my subscriber user
  Then updates to my subscriber user are preserved

Scenario: Subscriber user can not modify a subscriber user that is not self
  Given I am an subscriber user
  And I try to modify a subscriber user
  Then I get an unauthorized response


## User Deletion

Scenario: Admin user can delete an admin user
  Given I am an admin user
  And I try to delete an admin user
  Then I get a response indicating the deletion was successful

Scenario: Admin user can not delete their own an admin user
  Given I am an admin user
  And I try to delete my admin user
  Then I get an forbidden response

Scenario: Admin user can delete an editor user
  Given I am an admin user
  And I try to delete the editor user
  Then I get a response indicating the deletion was successful

Scenario: Admin user can delete an subscriber user
  Given I am an admin user
  And I try to delete a subscriber user
  Then I get a response indicating the deletion was successful

Scenario: Editor user can not delete an admin user
  Given I am an editor user
  And I try to delete an admin user
  Then I get an unauthorized response

Scenario: Editor user can not delete an editor user
  Given I am an editor user
  And I try to delete an editor user
  Then I get an unauthorized response

Scenario: Editor user can not delete an editor user
  Given I am an editor user
  And I try to delete a subscriber user
  Then I get an unauthorized response
