"""
Utilities for testing.

:copyright: Copyright 2013-2016, Dorian Pula <dorian.pula@amber-penguin-software.ca>
:license: AGPL v3+
"""

import sqlalchemy
from werkzeug import security
from rookeries.users import models


def create_test_user(db_engine, username, password, role=models.UserRole.subscriber, full_name='Test User',
                     email_address='test@test.rookeries.org'):
    """
    Creates or returns an existing test user by username.

    :param db_engine: The DB engine to spawn a session from.
    :param username: The username of the test user.
    :param password: The password for the test user.
    :param role: The role of the user.  Defaults to subscriber.
    :param full_name: The full name of the user.
    :param email_address: The email address of the user.
    :return: A test user.
    """

    session = sqlalchemy.orm.sessionmaker(bind=db_engine, autocommit=True)()
    session.begin()
    test_user = session.query(models.User).filter_by(username=username).first()
    if not test_user:
        test_user = models.User(username)
        test_user.password = security.generate_password_hash(password)
        test_user.role = role

        test_user_profile = models.UserProfile()
        test_user_profile.full_name = full_name
        test_user_profile.email = email_address
        test_user.profile = test_user_profile

        session.add(test_user)
        session.commit()

    test_user = session.query(models.User).filter_by(username=username).first()
    test_user_json = test_user.to_json()
    session.close()
    return test_user_json
